package com.muyu.task.server.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.StringUtils;
import com.muyu.common.domain.DataValue;
import com.muyu.common.domian.NodeJoint;
import com.muyu.common.domian.TaskInput;
import com.muyu.common.domian.req.TaskInputListReq;
import com.muyu.task.server.feign.DatasourceFeign;
import com.muyu.task.server.mapper.TaskInputMapper;
import com.muyu.task.server.service.NodeJointService;
import com.muyu.task.server.service.NodeTableService;
import com.muyu.task.server.service.TaskInputService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.util.HashSet;
import java.util.List;

@Service
public class TaskInputServiceImpl extends ServiceImpl<TaskInputMapper, TaskInput> implements TaskInputService {
    @Autowired
    private TaskInputMapper taskInputMapper;

    @Autowired
    private NodeTableService tableService;

    @Autowired
    private NodeJointService nodeJointService;

    @Autowired
    private DatasourceFeign datasourceFeign;


    @Override
    public Page<TaskInput> findList(TaskInputListReq req) {
        LambdaQueryWrapper<TaskInput> wrapper = new LambdaQueryWrapper<>();
        wrapper.like(StringUtils.isNotEmpty(req.getNodeName()), TaskInput::getNodeName, req.getNodeName());
        Page<TaskInput> page = new Page<>(req.getPageNum(), req.getPageSize());
        page.setTotal(this.count(wrapper));
        return this.page(page, wrapper);
    }


    @Override
    public String findByFieName(Long taskId) {
        QueryWrapper<TaskInput> wrapper = new QueryWrapper<>();
        wrapper.eq("task_id", taskId);
        HashSet<Long> longs = new HashSet<>();
        List<TaskInput> list = taskInputMapper.selectList(wrapper);
        if (CollectionUtils.isEmpty(list)) {
            return "没有选择字段";
        }
        String fieName = "";
        for (int i = 0; i < list.size(); i++) {
            fieName += "," + list.get(i).getTableAsFieId();
            Long databaseId = list.get(i).getDatabaseId();
            longs.add(databaseId);
        }
        if (longs.size() > 1) {
            return "你选择的不是同一个数据库";
        }
        QueryWrapper<NodeJoint> jointQueryWrapper = new QueryWrapper<>();
        jointQueryWrapper.eq("task_id", taskId);
        List<NodeJoint> jointList = nodeJointService.list(jointQueryWrapper);
        String joint = "";
        if (!CollectionUtils.isEmpty(jointList)){
            for (NodeJoint nodeJoint : jointList) {
                String oneNodeId = nodeJoint.getOneNodeId();
                TaskInput taskInput = taskInputMapper.selectByNodeId(oneNodeId);
                String tableName = taskInput.getTableName();
                String tableAsName = taskInput.getTableAsName();

                String twoNodeId = nodeJoint.getTwoNodeId();
                TaskInput taskInputTwo = taskInputMapper.selectByNodeId(twoNodeId);
                String tableNameTwo = taskInputTwo.getTableName();
                String tableAsNameTwo = taskInputTwo.getTableAsName();

                joint += " " + tableName + " " + " " + tableAsName + " " + nodeJoint.getJoint() + " " + tableNameTwo + " " + " " + tableAsNameTwo + " "
                        + " on " +nodeJoint.getOneFie() +"="+nodeJoint.getTwoFie();

            }
        }else {
            TaskInput taskInput = taskInputMapper.selectByTaskId(taskId);
            String tableName = taskInput.getTableName();
            String tableAsName = taskInput.getTableAsName();
            joint=" "+tableName+" "+tableAsName;
        }
        TaskInput taskInput = taskInputMapper.selectByTaskId(taskId);
        Long databaseId = taskInput.getDatabaseId();
        fieName = fieName.substring(1);
        String sql="select "+fieName + "  form "+joint;
        System.out.println("select "+fieName + "  from "+joint);
        Result<List<List<DataValue>>> tableValue = datasourceFeign.findTableValue(databaseId, sql);
        System.out.println(tableValue);
        return null;
    }
}
